@@ -1,20 +1,21 @@
 import os, subprocess
 import fileinput
 import shutil
-from revChatGPT.Official import Chatbot
+from revChatGPT.V2 import Chatbot
 
 def replace_value(line, field, value):
     if field in line:
         line = line.replace(field, value)
     return line
 
-def generateCoverLetter(job_listing, company_name, address1, address2):
+async def generateCoverLetter(job_listing, company_name, address1, address2):
     script_dir = os.path.dirname(os.path.realpath(__file__))
 
-    # read api key from file
-    api_key_file = os.path.join(script_dir, "api_key")
+    # read user credentials from file
+    api_key_file = os.path.join(script_dir, "login")
     with open(api_key_file, "r") as f:
-        api_key = f.read()
+        user_email = f.readline().strip()
+        user_password = f.readline().strip()
 
     # read settings from file
     settings_file = os.path.join(script_dir, "settings")
@@ -30,19 +31,20 @@ def generateCoverLetter(job_listing, company_name, address1, address2):
     if os.path.exists(rawresume_file):
         with open(rawresume_file, "r", encoding="UTF-8", errors='ignore') as f:
             resume = f.read()
-        message = "Write a cover letter for this job position: " + company_name + " " + job_listing + "\n This is my resume: \n" + resume
+        message = "Write a cover letter without a letter closing for this job position: " + company_name + " " + job_listing + "\n This is my resume: \n" + resume
         message = "".join(c for c in message if c <= "\uFFFF")
     else:
-        message = "Write a cover letter for this job position: " + company_name + " " + job_listing
+        message = "Write a cover letter without a letter closing for this job position: " + company_name + " " + job_listing
 
     print(message)
-    chatbot = Chatbot(api_key)
-    response = chatbot.ask(message, 0.5) # increasing temperature resulted in less coherent responses
+    chatbot = Chatbot(email=user_email, password=user_password)
+    
+    body = ""
+    async for content in chatbot.ask(message):
+        body += content["choices"][0]["text"].replace("<|im_end|>", "")
+    print(body)
 
-    content = response["choices"][0]["text"]
-    print(content)
-
-    paragraphs = content.split("\n\n")
+    paragraphs = body.split("\n\n")
 
     template_file = os.path.join(script_dir, "template.tex")
     coverletter_file = os.path.join(script_dir, "coverletter.tex")
@@ -64,7 +66,7 @@ def generateCoverLetter(job_listing, company_name, address1, address2):
             line = replace_value(line, field, value)
         print(line, end='')
 
-    for i in range(1, len(paragraphs)-1):
+    for i in range(1, len(paragraphs) - 1):
         file_path = os.path.join(script_dir, "coverletter.tex")
         for line in fileinput.input(file_path, inplace=True, backup=".bak"):
             if line.strip() == "\\vspace{0.5cm}":
